summaryrefslogtreecommitdiff
path: root/svtools
diff options
context:
space:
mode:
authorMichael Stahl <mstahl@redhat.com>2014-02-20 00:36:57 +0100
committerMichael Stahl <mstahl@redhat.com>2014-02-20 00:52:22 +0100
commit96a1f60aeb2a7954533da9b4aa4947efb7a65e70 (patch)
tree104bfa02e5ea23b1651c42d09d1bcc68d60695cf /svtools
parent76fc71a989b0059c78f4898694e7fa57ebed9248 (diff)
fdo#74584: Revert "html: Options need to be lowercase, too"
This reverts commit 700883b34ebcdb77f398b4423f358bdf4648a853. ...since 73e3aafa990168aa532fa7b81fc4de8f455b10e1 was reverted and sw_htmlexport test fails. Change-Id: Ia83705279e792a0c2375619b6a209e46a319fea7
Diffstat (limited to 'svtools')
-rw-r--r--svtools/source/svhtml/parhtml.cxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/svtools/source/svhtml/parhtml.cxx b/svtools/source/svhtml/parhtml.cxx
index 6517e5c8ca92..08ec21a84b65 100644
--- a/svtools/source/svhtml/parhtml.cxx
+++ b/svtools/source/svhtml/parhtml.cxx
@@ -1462,8 +1462,10 @@ const HTMLOptions& HTMLParser::GetOptions( sal_uInt16 *pNoConvertToken )
OUString sName( aToken.copy( nStt, nPos-nStt ) );
- // PlugIns require original token name. Convert to lower case only for searching.
- nToken = GetHTMLOption( sName.toAsciiLowerCase() ); // Name is ready
+ // PlugIns require original token name. Convert to upper case only for searching.
+ OUString sNameUpperCase( sName.toAsciiUpperCase() );
+
+ nToken = GetHTMLOption( sNameUpperCase ); // Name is ready
DBG_ASSERTWARNING( nToken!=HTML_O_UNKNOWN,
"GetOption: unknown HTML option" );
bool bStripCRLF = (nToken < HTML_OPTION_SCRIPT_START ||